@@ -44,7 +44,8 @@ class Client(object):
                 return "Vanity is not found!"
             else:
                 if self.debugMode == True:
-                    print(f"Raw data found: {vanity}")
+                    print(f"Raw data found: {json.loads(vanity)}")
+
                 return objects.vanityData(json.loads(vanity))
                 
 
